@@ -1,9 +1,9 @@
-package MooseX::Storage;
-# git description: v0.46-17-g342ddd4
-$MooseX::Storage::VERSION = '0.47';
+package MooseX::Storage; # git description: v0.49-9-gee3daf7
 # ABSTRACT: A serialization framework for Moose classes
 # KEYWORDS: moose extension serial serialization class object store storage types strings
 
+our $VERSION = '0.50';
+
 use Moose 0.99;
 use MooseX::Storage::Meta::Attribute::DoNotSerialize;
 use String::RewritePrefix ();
@@ -119,7 +119,7 @@ MooseX::Storage - A serialization framework for Moose classes
 
 =head1 VERSION
 
-version 0.47
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,7 @@ to a number of different formats and styles.
 
 =head2 Levels of Serialization
 
-There are 3 levels to the serialization, each of which builds upon
+There are three levels to the serialization, each of which builds upon
 the other and each of which can be customized to the specific needs
 of your class.
 
@@ -264,14 +264,14 @@ See L<MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize> for details.
 
 =head2 How we serialize
 
-There are always limits to any serialization framework, there are just
+There are always limits to any serialization framework -- there are just
 some things which are really difficult to serialize properly and some
 things which cannot be serialized at all.
 
 =head2 What can be serialized?
 
 Currently only numbers, string, ARRAY refs, HASH refs and other
-MooseX::Storage enabled objects are supported.
+MooseX::Storage-enabled objects are supported.
 
 With Array and Hash references the first level down is inspected and
 any objects found are serialized/deserialized for you. We do not do
@@ -281,7 +281,7 @@ option eventually.
 =for stopwords subtypes
 
 The specific serialize/deserialize routine is determined by the
-Moose type constraint a specific attribute has. In most cases subtypes
+L<Moose> type constraint a specific attribute has. In most cases subtypes
 of the supported types are handled correctly, and there is a facility
 for adding handlers for custom types as well. This will get documented
 eventually, but it is currently still in development.
@@ -289,7 +289,7 @@ eventually, but it is currently still in development.
 =head2 What can not be serialized?
 
 We do not support CODE references yet, but this support might be added
-in using B::Deparse or some other deep magic.
+in using L<B::Deparse> or some other deep magic.
 
 Scalar refs are not supported, mostly because there is no way to know
 if the value being referenced will be there when the object is inflated.
@@ -369,8 +369,8 @@ in the #moose channel on irc.perl.org.
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+exception. If you find a bug please or add the bug to cpan-RT
+at L<https://rt.cpan.org/Dist/Display.html?Queue=MooseX-Storage>.
 
 =head1 AUTHORS
 
@@ -399,7 +399,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Tomas Doran Ricardo Signes Chris Prather Yuval Kogman Jos Boumans Shawn M Moore Jonathan Yu Robert Boone Dagfinn Ilmari Mannsåker Cory Watson Dan Brook David Steinbrunner Jason Pope Johannes Plunien Rockway Florian Ragwitz Golden
+=for stopwords Karen Etheridge Tomas Doran Ricardo Signes Chris Prather Jos Boumans Shawn M Moore Jonathan Yu Dagfinn Ilmari Mannsåker Dmitry Latin Cory Watson Robert Boone sillitoe Dan Brook David Golden Steinbrunner Florian Ragwitz Jason Pope Johannes Plunien Rockway
 
 =over 4
 
@@ -421,10 +421,6 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Yuval Kogman <nothingmuch@woobling.org>
-
-=item *
-
 Jos Boumans <jos@dwim.org>
 
 =item *
@@ -437,11 +433,11 @@ Jonathan Yu <frequency@cpan.org>
 
 =item *
 
-Robert Boone <robo4288@gmail.com>
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 =item *
 
-Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+Dmitry Latin <dim0xff@gmail.com>
 
 =item *
 
@@ -449,14 +445,30 @@ Cory Watson <gphat@Crankwizzah.local>
 
 =item *
 
+Robert Boone <robo4288@gmail.com>
+
+=item *
+
+sillitoe <ian@sillit.com>
+
+=item *
+
 Dan Brook <dan@broquaint.com>
 
 =item *
 
+David Golden <dagolden@cpan.org>
+
+=item *
+
 David Steinbrunner <dsteinbrunner@pobox.com>
 
 =item *
 
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
 Jason Pope <cowholio4@gmail.com>
 
 =item *
@@ -467,14 +479,6 @@ Johannes Plunien <plu@pqpq.de>
 
 Jonathan Rockway <jon@jrock.us>
 
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
-David Golden <dagolden@cpan.org>
-
 =back
 
 =cut
