@@ -1,6 +1,8 @@
 package MooseX::Storage::Format::YAML;
 # ABSTRACT: A YAML serialization role
-$MooseX::Storage::Format::YAML::VERSION = '0.48';
+
+our $VERSION = '0.50';
+
 use Moose::Role;
 
 # When I add YAML::LibYAML
@@ -39,7 +41,7 @@ MooseX::Storage::Format::YAML - A YAML serialization role
 
 =head1 VERSION
 
-version 0.48
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -97,8 +99,8 @@ version 0.48
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+exception. If you find a bug please or add the bug to cpan-RT
+at L<https://rt.cpan.org/Dist/Display.html?Queue=MooseX-Storage>.
 
 =head1 AUTHORS
 
