@@ -1,6 +1,8 @@
 package MooseX::Storage::IO::AtomicFile;
 # ABSTRACT: An Atomic File I/O role
-$MooseX::Storage::IO::AtomicFile::VERSION = '0.48';
+
+our $VERSION = '0.50';
+
 use Moose::Role;
 use MooseX::Storage::Engine::IO::AtomicFile;
 use namespace::autoclean;
@@ -28,7 +30,7 @@ MooseX::Storage::IO::AtomicFile - An Atomic File I/O role
 
 =head1 VERSION
 
-version 0.48
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -73,8 +75,8 @@ version 0.48
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+exception. If you find a bug please or add the bug to cpan-RT
+at L<https://rt.cpan.org/Dist/Display.html?Queue=MooseX-Storage>.
 
 =head1 AUTHORS
 
