@@ -1,12 +1,10 @@
 package MooseX::Storage::Traits::DisableCycleDetection;
-{
-  $MooseX::Storage::Traits::DisableCycleDetection::VERSION = '0.45';
-}
-BEGIN {
-  $MooseX::Storage::Traits::DisableCycleDetection::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A custom trait to bypass cycle detection
+
+our $VERSION = '0.50';
+
 use Moose::Role;
+use namespace::autoclean;
 
 requires 'pack';
 requires 'unpack';
@@ -35,19 +33,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Florian Ragwitz Johannes Plunien Jonathan Rockway Yu Jos
-Boumans Karen Etheridge Ricardo Signes Robert Boone Shawn M Moore Tomas
-Doran Cory Yuval Kogman Watson Dagfinn Ilmari Mannsåker David Golden
-Steinbrunner culted
-
 =head1 NAME
 
 MooseX::Storage::Traits::DisableCycleDetection - A custom trait to bypass cycle detection
 
 =head1 VERSION
 
-version 0.45
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -75,6 +67,8 @@ references, so if you know what you are doing, you can bypass this check.
 This trait is applied to all objects that inherit from it. To use this
 on a per-case basis, see C<disable_cycle_check> in L<MooseX::Storage::Basic>.
 
+=for stopwords culted
+
 See the SYNOPSIS for a nice example that can be easily cargo-culted.
 
 =head1 METHODS
@@ -90,8 +84,8 @@ See the SYNOPSIS for a nice example that can be easily cargo-culted.
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+exception. If you find a bug please or add the bug to cpan-RT
+at L<https://rt.cpan.org/Dist/Display.html?Queue=MooseX-Storage>.
 
 =head1 AUTHORS
 
