@@ -1,12 +1,10 @@
 package MooseX::Storage::Traits::OnlyWhenBuilt;
-{
-  $MooseX::Storage::Traits::OnlyWhenBuilt::VERSION = '0.45';
-}
-BEGIN {
-  $MooseX::Storage::Traits::OnlyWhenBuilt::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A custom trait to bypass serialization
+
+our $VERSION = '0.50';
+
 use Moose::Role;
+use namespace::autoclean;
 
 requires 'pack';
 requires 'unpack';
@@ -35,19 +33,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
-Interactive, Inc. Florian Ragwitz Johannes Plunien Jonathan Rockway Yu Jos
-Boumans Karen Etheridge Ricardo Signes Robert Boone Shawn M Moore Tomas
-Doran Cory Yuval Kogman Watson Dagfinn Ilmari Mannsåker David Golden
-Steinbrunner culted
-
 =head1 NAME
 
 MooseX::Storage::Traits::OnlyWhenBuilt - A custom trait to bypass serialization
 
 =head1 VERSION
 
-version 0.45
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -81,6 +73,8 @@ as outlined in the C<Synopsis>, only attributes that have been built
 (i.e., where the predicate returns 'true') will be serialized.
 This avoids any potentially expensive computations.
 
+=for stopwords culted
+
 See the SYNOPSIS for a nice example that can be easily cargo-culted.
 
 =head1 METHODS
@@ -96,8 +90,8 @@ See the SYNOPSIS for a nice example that can be easily cargo-culted.
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+exception. If you find a bug please or add the bug to cpan-RT
+at L<https://rt.cpan.org/Dist/Display.html?Queue=MooseX-Storage>.
 
 =head1 AUTHORS
 
